==> realestate-supervise-common-1.1.0-20250924.014108-69-sources.jar: cn/gtmap/realestate/supervise/entity/BaTdsyq.java <==
package cn.gtmap.realestate.supervise.entity;


import cn.gtmap.realestate.supervise.core.reflect.*;
import com.sun.istack.internal.Nullable;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.*;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:gaofeng@gtmap.cn">gaofeng</a>
 * @version 1.0，2017/6/15
 * @description 土地所有权
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlRootElement
@XmlType
@Entity
@Table(
        name = "ba_tdsyq"
)
public class BaTdsyq implements Serializable {

    @XmlAttribute
    @id
    @Id
    private String id;

    @XmlAttribute
    private String ysdm;

    @XmlAttribute
    private String zddm;

    @XmlAttribute
    private String bdcdyh;

    @XmlAttribute
    @Nullable
    @ywh
    private String ywh;

    @XmlAttribute
    private String qllx;

    @XmlAttribute
    private String djlx;

    @XmlAttribute
    private String djyy;

    @XmlAttribute
    private String mjdw;

    @XmlAttribute
    @Nullable
    private String nydmj;

    @XmlAttribute
    @Nullable
    private String gdmj;

    @XmlAttribute
    @Nullable
    private String ldmj;

    @XmlAttribute
    @Nullable
    private String cdmj;

    @XmlAttribute
    @Nullable
    private String qtnydmj;

    @XmlAttribute
    @Nullable
    private String jsydmj;

    @XmlAttribute
    @Nullable
    private String wlydmj;

    @XmlAttribute
    private String bdcqzh;

    @XmlAttribute
    @qxdm
    private String qxdm;

    @XmlAttribute
    private String djjg;

    @XmlAttribute
    private String dbr;

    @XmlAttribute
    private Date djsj;

    @XmlAttribute
    @Nullable
    private String fj;

    @XmlAttribute
    private String qszt;

    @Nullable
    private Date sjgxsj;

    @bwmc
    private String bwmc;

    @XmlAttribute
    @ssywh
    private String ssywh;

    @XmlAttribute
    private String yt;

    @sqlx
    private String sqlx;

    public String getSqlx() {
        return sqlx;
    }

    public void setSqlx(String sqlx) {
        this.sqlx = sqlx;
    }

    public String getSsywh() {
        return ssywh;
    }

    public void setSsywh(String ssywh) {
        this.ssywh = ssywh;
    }

    public String getYt() {
        return yt;
    }

    public void setYt(String yt) {
        this.yt = yt;
    }

    public String getBwmc() {
        return bwmc;
    }

    public void setBwmc(String bwmc) {
        this.bwmc = bwmc;
    }

    public Date getSjgxsj() {
        return sjgxsj;
    }

    public void setSjgxsj(Date sjgxsj) {
        this.sjgxsj = sjgxsj;
    }

    public String getYsdm() {
        return ysdm;
    }

    public String getZddm() {
        return zddm;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public String getYwh() {
        return ywh;
    }

    public String getQllx() {
        return qllx;
    }

    public String getDjlx() {
        return djlx;
    }

    public String getDjyy() {
        return djyy;
    }

    public String getMjdw() {
        return mjdw;
    }

    public String getNydmj() {
        return nydmj;
    }

    public String getGdmj() {
        return gdmj;
    }

    public String getLdmj() {
        return ldmj;
    }

    public String getCdmj() {
        return cdmj;
    }

    public String getQtnydmj() {
        return qtnydmj;
    }

    public String getJsydmj() {
        return jsydmj;
    }

    public String getWlydmj() {
        return wlydmj;
    }

    public String getBdcqzh() {
        return bdcqzh;
    }

    public String getQxdm() {
        return qxdm;
    }

    public String getDjjg() {
        return djjg;
    }

    public String getDbr() {
        return dbr;
    }

    public Date getDjsj() {
        return djsj;
    }

    public String getFj() {
        return fj;
    }

    public String getQszt() {
        return qszt;
    }


    public void setYsdm(String ysdm) {
        this.ysdm = ysdm;
    }

    public void setZddm(String zddm) {
        this.zddm = zddm;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    public void setDjyy(String djyy) {
        this.djyy = djyy;
    }

    public void setMjdw(String mjdw) {
        this.mjdw = mjdw;
    }

    public void setNydmj(String nydmj) {
        this.nydmj = nydmj;
    }

    public void setGdmj(String gdmj) {
        this.gdmj = gdmj;
    }

    public void setLdmj(String ldmj) {
        this.ldmj = ldmj;
    }

    public void setCdmj(String cdmj) {
        this.cdmj = cdmj;
    }

    public void setQtnydmj(String qtnydmj) {
        this.qtnydmj = qtnydmj;
    }

    public void setJsydmj(String jsydmj) {
        this.jsydmj = jsydmj;
    }

    public void setWlydmj(String wlydmj) {
        this.wlydmj = wlydmj;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    public void setDjjg(String djjg) {
        this.djjg = djjg;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public void setQszt(String qszt) {
        this.qszt = qszt;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }
}

==> realestate-supervise-common-1.1.0-20251204.013828-71-sources.jar: cn/gtmap/realestate/supervise/entity/BaTdsyq.java <==
package cn.gtmap.realestate.supervise.entity;


import cn.gtmap.realestate.supervise.core.reflect.*;
import com.sun.istack.internal.Nullable;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.*;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:gaofeng@gtmap.cn">gaofeng</a>
 * @version 1.0，2017/6/15
 * @description 土地所有权
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlRootElement
@XmlType
@Entity
@Table(
        name = "ba_tdsyq"
)
public class BaTdsyq implements Serializable {

    @XmlAttribute
    @id
    @Id
    private String id;

    @XmlAttribute
    private String ysdm;

    @XmlAttribute
    private String zddm;

    @XmlAttribute
    private String bdcdyh;

    @XmlAttribute
    @Nullable
    @ywh
    private String ywh;

    @XmlAttribute
    private String qllx;

    @XmlAttribute
    private String djlx;

    @XmlAttribute
    private String djyy;

    @XmlAttribute
    private String mjdw;

    @XmlAttribute
    @Nullable
    private String nydmj;

    @XmlAttribute
    @Nullable
    private String gdmj;

    @XmlAttribute
    @Nullable
    private String ldmj;

    @XmlAttribute
    @Nullable
    private String cdmj;

    @XmlAttribute
    @Nullable
    private String qtnydmj;

    @XmlAttribute
    @Nullable
    private String jsydmj;

    @XmlAttribute
    @Nullable
    private String wlydmj;

    @XmlAttribute
    private String bdcqzh;

    @XmlAttribute
    @qxdm
    private String qxdm;

    @XmlAttribute
    private String djjg;

    @XmlAttribute
    private String dbr;

    @XmlAttribute
    private Date djsj;

    @XmlAttribute
    @Nullable
    private String fj;

    @XmlAttribute
    private String qszt;

    @Nullable
    private Date sjgxsj;

    @bwmc
    private String bwmc;

    @XmlAttribute
    @ssywh
    private String ssywh;

    @XmlAttribute
    private String yt;

    @sqlx
    private String sqlx;

    // ============73696 江苏省级_地籍数据监管模块总体需求新增字段开始===============

    // 用地用海分类代码
    @XmlAttribute
    private String ydyhfldm;

    /** 监管标识码 */
    @jgbsm
    private String jgbsf;

    /** 登记状态 */
    @XmlAttribute
    private String djzt;

    // ============73696 江苏省级_地籍数据监管模块总体需求新增字段结束===============

    public String getSqlx() {
        return sqlx;
    }

    public void setSqlx(String sqlx) {
        this.sqlx = sqlx;
    }

    public String getSsywh() {
        return ssywh;
    }

    public void setSsywh(String ssywh) {
        this.ssywh = ssywh;
    }

    public String getYt() {
        return yt;
    }

    public void setYt(String yt) {
        this.yt = yt;
    }

    public String getBwmc() {
        return bwmc;
    }

    public void setBwmc(String bwmc) {
        this.bwmc = bwmc;
    }

    public Date getSjgxsj() {
        return sjgxsj;
    }

    public void setSjgxsj(Date sjgxsj) {
        this.sjgxsj = sjgxsj;
    }

    public String getYsdm() {
        return ysdm;
    }

    public String getZddm() {
        return zddm;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public String getYwh() {
        return ywh;
    }

    public String getQllx() {
        return qllx;
    }

    public String getDjlx() {
        return djlx;
    }

    public String getDjyy() {
        return djyy;
    }

    public String getMjdw() {
        return mjdw;
    }

    public String getNydmj() {
        return nydmj;
    }

    public String getGdmj() {
        return gdmj;
    }

    public String getLdmj() {
        return ldmj;
    }

    public String getCdmj() {
        return cdmj;
    }

    public String getQtnydmj() {
        return qtnydmj;
    }

    public String getJsydmj() {
        return jsydmj;
    }

    public String getWlydmj() {
        return wlydmj;
    }

    public String getBdcqzh() {
        return bdcqzh;
    }

    public String getQxdm() {
        return qxdm;
    }

    public String getDjjg() {
        return djjg;
    }

    public String getDbr() {
        return dbr;
    }

    public Date getDjsj() {
        return djsj;
    }

    public String getFj() {
        return fj;
    }

    public String getQszt() {
        return qszt;
    }


    public void setYsdm(String ysdm) {
        this.ysdm = ysdm;
    }

    public void setZddm(String zddm) {
        this.zddm = zddm;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    public void setDjyy(String djyy) {
        this.djyy = djyy;
    }

    public void setMjdw(String mjdw) {
        this.mjdw = mjdw;
    }

    public void setNydmj(String nydmj) {
        this.nydmj = nydmj;
    }

    public void setGdmj(String gdmj) {
        this.gdmj = gdmj;
    }

    public void setLdmj(String ldmj) {
        this.ldmj = ldmj;
    }

    public void setCdmj(String cdmj) {
        this.cdmj = cdmj;
    }

    public void setQtnydmj(String qtnydmj) {
        this.qtnydmj = qtnydmj;
    }

    public void setJsydmj(String jsydmj) {
        this.jsydmj = jsydmj;
    }

    public void setWlydmj(String wlydmj) {
        this.wlydmj = wlydmj;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    public void setDjjg(String djjg) {
        this.djjg = djjg;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public void setQszt(String qszt) {
        this.qszt = qszt;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getYdyhfldm() {
        return ydyhfldm;
    }

    public void setYdyhfldm(String ydyhfldm) {
        this.ydyhfldm = ydyhfldm;
    }

    public String getJgbsf() {
        return jgbsf;
    }

    public void setJgbsf(String jgbsf) {
        this.jgbsf = jgbsf;
    }

    public String getDjzt() {
        return djzt;
    }

    public void setDjzt(String djzt) {
        this.djzt = djzt;
    }
}
